NLSL: basis.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

basis.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/9/15
2 c----------------------------------------------------------------------
3 c =========================
4 c module BASIS
5 c =========================
6 c
7 c Contains common block for storage of basis set index lists.
8 c Module nlsdim is used by this module.
9 c
10 c ibasis: block containing basis indices
11 c basno: number of block with basis set for a given site,spectrum
12 c ixbas: Index of basis set block used by each set
13 c ltbas: Length of basis set block used by each set
14 c bsused: Flag indicating whether set is in use
15 c nbas: Number of currently defined basis sets
16 c nextbs: Next available element of storage block
17 c basisID: Filenames from which pruned basis sets were read
18 c----------------------------------------------------------------------
19 module basis
20 use nlsdim
21 implicit none
22 c
23 integer, save :: ibasis(5,mxdim),basno(mxsite,mxspc),
24 # mts(9,mxmts),ixbas(mxtdm),ltbas(mxtdm),
25 # bsused(mxtdm),nbas,nextbs
26 c
27 character*30, save :: basisid(mxtdm)
28 c
29 end module basis
basis::bsused
integer, dimension(mxtdm), save bsused
Definition: basis.f90:23
basis::ibasis
integer, dimension(5, mxdim), save ibasis
Definition: basis.f90:23
basis::basisid
character *30, dimension(mxtdm), save basisid
Definition: basis.f90:27
basis::basno
integer, dimension(mxsite, mxspc), save basno
Definition: basis.f90:23
nlsdim::mxmts
integer, parameter mxmts
Definition: nlsdim.f90:39
nlsdim::mxtdm
integer, parameter mxtdm
Definition: nlsdim.f90:39
basis
Definition: basis.f90:19
basis::mts
integer, dimension(9, mxmts), save mts
Definition: basis.f90:23
nlsdim::mxspc
integer, parameter mxspc
Definition: nlsdim.f90:39
basis::nextbs
integer, save nextbs
Definition: basis.f90:23
nlsdim::mxsite
integer, parameter mxsite
Definition: nlsdim.f90:39
nlsdim
Definition: nlsdim.f90:36
nlsdim::mxdim
integer, parameter mxdim
Definition: nlsdim.f90:39
basis::nbas
integer, save nbas
Definition: basis.f90:23
basis::ixbas
integer, dimension(mxtdm), save ixbas
Definition: basis.f90:23
basis::ltbas
integer, dimension(mxtdm), save ltbas
Definition: basis.f90:23